# -*- coding: cp1252 -*-

import Ly, lys
import re
import sys


regex_filevalid = re.compile(r'^(([a-zA-Z]:|\\)\\)?(((\.)|(\.\.)|([^\\/:\*\?"\|<>\. ](([^\\/:\*\?"\|<>\. ])|([^\\/:\*\?"\|<>]*[^\\/:\*\?"\|<>\. ]))?))\\)*[^\\/:\*\?"\|<>\. ](([^\\/:\*\?"\|<>\. ])|([^\\/:\*\?"\|<>]*[^\\/:\*\?"\|<>\. ]))?$')


def checkString(stringToCheck):
    return len(re.findall(regex_filevalid, stringToCheck)) > 0


class info(object):
    # Das info-Objekt speichert die Einstellungen, die man im Dialog ndern kann.
    def __init__( self ):
        # Modul
        # - In diesem Modul nicht verwendet, sonst zB  self.modul_zeitbasis = "Treiber" o..
        # Kanal
        # - Fr jeden der 16 Kanle den Wert vorbelegen.
        self.kanal_stringnummer_quelle = [n for n in range(1,17)]  # Kanal0=1, Kanal1=2,.., Kanal15=16
        self.kanal_stringnummer_ziel = [n+16 for n in range(1,17)]  # Kanal0=2, Kanal1=3,.., Kanal15=17

    
class var(object):
    def __init__( self ):
        pass


class pscript(Ly.Mclass):

    # beim Laden eines Schaltbilds und beim Laden einen Skripts ins Modul
    def __init__(self, magic):
        self.info = info()
        self.MeasurementRunning = False


    # beim Laden eines Skripts ins Modul
    # festlegen, wie viele Ein-/Ausgnge das Modul direkt nach dem Reinziehen
    # ins Schaltbild haben soll. Die Kanalrelation bestimmt, wie viele
    # Eingnge Ausgngen zugeordnet sein sollen (siehe zB Arithmetik: Eingang 1+2=Ausgang1)
    def Create(self):
        self.NumInChannel = 1
        self.NumOutChannel = 0
        self.ChannelRelation = Ly.CR_NORMAL
        return True


    # Hilfsmethode: ausgrauen von Einstellungen beim ffnen des Dialogs,
    #  falls Messung luft, sonst nicht
    def DlgPropertyControl(self, dlg, props):
        state = (not self.MeasurementRunning) # deaktivieren/False, wenn Messung luft, aktiv sonst
        for page, prop in props:
            dlg.opt.SelectPage(page)
            dlg.opt.EnableProperty(prop, state)
    #end DlgPropertyControl


    # beim Doppelklick auf's Modul: Dialog-Optionen zusammenstellen
    def DlgInit(self, dlg):
        # Mindestens einen Kanalbutton/Stecker im Dialog
        self.DlgNumChannels = 1  #if self.NumInChannel < 1 else self.NumInChannel)
        self.DlgCurrChannel = 0
        self.DlgMaxChannels = 1  #Ly.MAX_CHANNELS

        dm = lys.DialogManager(self, dlg)

        # "modul values"
        dm.SelectModulePage()
        dm.AppendCategory("Modul-Einstellungen: keine!", "")
        # - In diesem Modul nicht verwendet.

        dm.SelectChannelPage()
        dm.AppendCategory("Kanal spezifische Einstellungen", "")
        dm.AppendInt("Stringnummer Quelle",
                     self.info.kanal_stringnummer_quelle,                     
                     desc="Nummer des globalen Strings, dessen Inhalt umgewandelt werden soll." \
                     +"\n1-999: Nummer der globalen Variable" )
        dm.AppendInt("Stringnummer Ziel",
                     self.info.kanal_stringnummer_ziel,
                     desc="Nummer des globalen Strings, der den umgewandelten Inhalt aufnimmt." \
                     +"\n1-999: Nummer der globalen Variable")

        # Festlegen, welche Meneintrge whrend der Messung deaktiviert werden sollen,
        # sodass sie vom Benutzer nicht mehr verstellt werden knnen.
        # (Dialogseite, Property name)
        DlgDeactivatableProperties = []
        DlgDeactivatableProperties.append((1,"Stringnummer Quelle"))
        DlgDeactivatableProperties.append((1,"Stringnummer Ziel"))
        self.DlgPropertyControl(dlg, DlgDeactivatableProperties)
    #end DlgInit
            

    # Dialog wird mit Ok-Taste verlassen
    # - Im Dialog vernderte Werte mssen nun noch ins info-Objekt gespeichert werden,
    #   damit DASYLab sie auch fr die Messung verwendet. Bisher stehen die Werte nur
    #   "im" Dialog.
    # - Prfen, ob die eingestellten werde auch einen Sinn ergeben.
    #   zB: Eine globale Variable mit Nummer ber 999 gibt es nicht.
    # - Sonstiges mit den eingestellten Werten anfangen:
    #   zB: Eingabe von 0 fhrt dazu, dass der empfangene Wert in
    #   keine globale Variable geschrieben wird. Siehe ProcessData.
    def DlgOk(self, dlg):
        
        def varInRange1To999(v):
            return (True if ((v >= 1) and (v <= 999)) else False)
        #end

        dom = lys.DialogOkManager(dlg)
        
        # Speichern der allgemeinen Moduleigenschaften:
        dom.SelectModulePage()
        # - keine
        
        # Speichern der Kanaleinstellungen
        dom.SelectChannelPage()
        
        # - jede eingegebene Nummer kanalweise prfen
        for channel in range(self.NumInChannel):
            if varInRange1To999(dom.GetValue("Stringnummer Quelle")[channel]) and \
               varInRange1To999(dom.GetValue("Stringnummer Ziel")[channel]):
                self.info.kanal_stringnummer_quelle[channel] = dom.GetValue("Stringnummer Quelle")[channel]
                self.info.kanal_stringnummer_ziel[channel] = dom.GetValue("Stringnummer Ziel")[channel]
            else:
                pass # nichts tun, falls eine Stringnummer kleiner 1 oder grer 999 eingegeben wurde.
        #end for
            
        self.SetConnectors(1,0)
    #end DlgOk
        

    # Dialog wird mit Abbrechen-Taste verlassen. Nichts zu tun.
    # Vernderte Einstellungen waren nur "im" Dialog gettigt.
    # Das info-Objekt hlt noch die unvernderten Werte.
    def DlgCancel(self, dlg):
        pass

        
    # Schaltbild wird gespeichert.
    def Save(self):
        pass


    # Schaltbild wird geladen.
    def Load(self):
        pass


    # Konfiguration der Ausgabe-FIFOs
    # - zB mit welcher Blockgre gibt das Modul Daten aus.
    # hier: Kein Ausgang vorhanden, also auch keine Konfiguration ntig.
    def SetupFifo(self, channel):
        pass


    # Die Messung wird gestartet.
    def Start(self):
        self.in_vorher = 0
        self.MeasurementRunning = True
    #end Start


    # Die Messung wird gestoppt.        
    def Stop(self):
        self.MeasurementRunning = False
    

    def ProcessData(self):
        
        inbuff = self.GetInputBlock(0)        
        if (inbuff is None):
            return True

        for blockpos in range(inbuff.BlockSize):
            if (inbuff[blockpos] - self.in_vorher) > 1.5:
                s = Ly.GetStr(self.info.kanal_stringnummer_quelle[0])
                isValid = checkString(s)
                Ly.SetStr(self.info.kanal_stringnummer_ziel[0], str(isValid))
            self.in_vorher = inbuff[blockpos]
        inbuff.Release()
        return True
    #end ProcessData
    
#end class
